==> tdiary_2.0.4.orig.tar.gz: tdiary-2.0.4/contrib2/plugin/tdiarytimes/tdiarytimes_textstyle.rb <==
# tdiarytimes_textstyle.rb $Revision: 1.1 $
#
# Copyright (c) 2004 phonondrive <tdiary@phonondrive.com>
# Distributed under the GPL
#
# ץ饰ۥڡ
# http://phonondrive.com/trd/
# --------------------------------------------------------------------
#
#
#
# Abstract
# --------------------------------------------------------------------
# ϿӤ򥿥饤˵Ͽޤ
# Ͽ줿ȥηвȶ˥եɥȤƤޤ
# Τ褦 MTBlogTimes  tdiarytimes ƱεǽƥȤǼ¸ޤ
# ޤƥȥ١Ǥ뤳Ȥʥȥǥ󤬲ǽǤ
# ruby-gd Υ󥹥ȡȤɬפʤᡢ˻ѽޤ
#
#
# Usage
# --------------------------------------------------------------------
# ץ饰ϡץ饰եƤ
# إå뤤ϥեåϤ <%= tdiarytimes_textstyle %>
# ΰ֤˥饤ʸŸޤ
# ȥεϿݻ֤β᤮Ťȥκϡ
# ɲäϿ˹Ԥޤ
# ȥΥեɥȸ̤ϥꥢ륿˷׻ޤ
# ȥɽʬǽ10ʬȤǤ
#
#
# Options
# --------------------------------------------------------------------
#
# ߡ9ĤΥץѰդƤޤ
#
# init_text	ϿƤʤӤʸ (Ǥդʸ)
# entr_text	Ͽ줿Ӥʸ (Ǥդʸ)
# init_color	ϿƤʤӤʸο (RRBBGGǻ)
# entr_color	Ͽ줿Ӥʸο (RRBBGGǻ)
# fade_color	Ͽ줿ӤʸΥեɥο (RRBBGGǻ)
# init_css	饤ʸΤCSS (CSSν񼰤˽)
# entr_css	Ͽ줿ӤʸCSS (CSSν񼰤˽)
# title_text	֥Ⱦ˥ޥݥȤTIPSʸ (Ǥդʸ)
# fade_time	Ȥ¸Ƥ(եɥȤפ) (Ǥդο)
# entr_interval	ΥȥϿְϿϿʤ (Ǥդο)
#
# ץͤˡˤ3Ĥˡꡢ̤ͥϼ̤Ǥ
# <%= tdiarytimes_textstyle %>   tdiary.conf  ǥե
# 
# entr_intervalƤΥץͤ <%= %> ؤΰˤ뤿ᡢ
# ڡˤȤ˰վѹʤɼͳ٤ι⤤ȥǥ󤬲ǽǤ
# ǡƤΥץ˥ǥեͤѰդƤ뤿ᡢ
# ԤʤƤưޤ
# ǥեͤζŪͤˤĤƤϡtdiary.confؤεˡι򻲾ȤƲ
#
#
# <%= tdiarytimes_textstyle %>ؤΰˤ륪ץˡ
# --------------------------------------------------------------------
#ڽ񼰡
# <%= tdiarytimes_textstyle init_text, entr_text, init_color, entr_color, fade_color, init_css, entr_css, title_text, fade_time %>
#
#ڵ 
# <%=tdiarytimes_textstyle "","","004400","66ff66","004400","background-color:#002200;font-size:9px",nil,"TEXTSTYLE!!",15 %>
#
#  tdiary.conf͡ޤϥǥեͤѤϡ nil ꤷƤ
#
#
# tdiary.confؤεҤˤ륪ץˡ
# --------------------------------------------------------------------
#ڵ (ȤƻꤵƤͤϡץ饰ΤλĥǥեͤǤ)
# @options['tdiarytimes_textstyle.init_text'] = "|"
# @options['tdiarytimes_textstyle.entr_text'] = "|"
# @options['tdiarytimes_textstyle.init_color'] = "444444"
# @options['tdiarytimes_textstyle.entr_color'] = "eeeeee"
# @options['tdiarytimes_textstyle.fade_color'] = "444444"
# @options['tdiarytimes_textstyle.init_css'] = "background-color:#444444;"
# @options['tdiarytimes_textstyle.entr_css'] = ""
# @options['tdiarytimes_textstyle.title_text'] = "TDIARYTIMES-TEXTSTYLE"
# @options['tdiarytimes_textstyle.fade_time'] = 30
# @options['tdiarytimes_textstyle.entr_interval'] = 1
#
#  fade_time ñ̤entr_interval ñ̤ϻ֤Ǥ
#  Ȥ¸Ƥ(եɥȴ)᤮ǡȥϡ
# ַвμɲû˥ե뤫ޤ
# δ֤ꤹ fade_time ͤϡ<%= %> ϻޤ
# ǥե(30)ʳͤѤϡɬ tdiary.conf ˤƻꤷƲ
# Ʊͤˡentr_interval ǥե(1)ʳꤷϡ
# tdiary.conf ˤƻꤷƲʤߤ0.530ʬֳ֤ˤʤޤ
#
#
# In secure mode
# --------------------------------------------------------------------
# ߤΤȤưޤ(եɤ߹ʤ)
#
#
# Acknowledgements
# --------------------------------------------------------------------
# This plugin is based on tdiarytimes.rb $Revision: 1.1 $
# Copyright (c) 2003 neuichi <neuichi@nmnl.jp>
# Distributed under the GPL
# http://nmnl.jp/hiki/software/?tDiary+%3A%3A+Plugin
#
#
=begin ChangeLog
2004.03.04 phonondrive  <tdiary@phonondrive.com>
   * version 1.0.4
	USER-AGENTꥹȤ򹹿ޤ

2004.02.05 phonondrive  <tdiary@phonondrive.com>
   * version 1.0.3
	եɥȸ̤η׻̤Ϥʤޤ

2004.01.30 phonondrive  <tdiary@phonondrive.com>
   * version 1.0.2
	Ͽֳ֤Υץ (entr_interval) ɲá
	ΥȥϿְϿϿʤ褦ˤޤ

2004.01.29 phonondrive  <tdiary@phonondrive.com>
   * version 1.0.1
	replace(Ͽ)⥨ȥϿ褦ˤޤ
	USER-AGENTθƤӽФˤϷ̤Ϥʤ褦ˤޤ
		Хü (tDiary)
		ƥȥ֥饦 (w3m, Lynx, links)
		CSSб֥饦 (Mosaic, Lite, iCab, JustView, WebExplorer)
		ܥå (bot, crawler, Spider, Slurp, inktomi, Sidewinder, naver)
		¾ (libwww, antenna)

2004.01.28 phonondrive  <tdiary@phonondrive.com>
   * version 1.0.0
=end




# tDiarytimes_textstyle η̤Ϥʤ USER-AGENT ꥹ
# Хüƥȥ֥饦CSSб֥饦ܥåȡƥʤʤ
# ʸʸ϶̤ޤ

def tdiarytimes_textstyle_ignore_user_agent; "w3m|Lynx|links|Mosaic|Lite|iCab|JustView|WebExplorer|bot|crawler|Spider|Slurp|inktomi|Sidewinder|naver|libwww|archiver|http|check|WDB|WWWC|WWWD|samidare|tamatebako|NATSU-MICAN|hina|antenna"; end




# --------------------------------------------------------------------
# Ͽν
# --------------------------------------------------------------------

if /^(append|replace)$/ =~ @mode then

	# ץ(ȥݻ)ɤ߹ߤ

	fade_time = @options['tdiarytimes_textstyle.fade_time'] || 30
	fade_time = 24 * 60 * 60 * fade_time.to_f

	entr_interval = @options['tdiarytimes_textstyle.entr_interval'] || 1
	entr_interval = 60 * 60 * entr_interval.to_f


	# ǡɤ߹

	cache = "#{@cache_path}/tdiarytimes_textstyle"
	Dir::mkdir( cache ) unless File::directory?( cache )

	begin
		io = open("#{cache}/tdiarytimes_textstyle.dat","r")
		ary_data =  Marshal.load(io)
		io.close

		# 1.0.1 >> 1.0.2 ǡܹ
		if ary_data.size == 144
			ary_data.push(Time.now.to_i - entr_interval - 1)
		end

	rescue
		# ʤϲǡѰ
		ary_data = Array.new(145) {|i| 0 }
	end


	# ɥǡ̿褿ȥ

	(0..143).each {|i|
		delta = (Time.now.to_i - ary_data[i])/fade_time.to_f
		if delta < 0 || delta > 1
			ary_data[i] = 0
		end
	}


	# Ͽֳ֤вᤷƤ顢Ͽ줿Ӥ˿ȥ򥻥åȤ

	if (Time.now.to_i - ary_data[144]) > entr_interval.to_f
		ary_data[(Time.now.strftime('%H').to_i*6 + Time.now.strftime('%M').to_f/10).to_i] = Time.now.to_i
		# ǽϿ֤εϿ
		ary_data[144] = Time.now.to_i 
	end


	# ǡν񤭹

	io = open("#{cache}/tdiarytimes_textstyle.dat","w")
		Marshal.dump(ary_data,io)
	io.close
end




# --------------------------------------------------------------------
# ץ饰ɽư
# --------------------------------------------------------------------

def tdiarytimes_textstyle (init_text = nil, entr_text = nil, init_color = nil, entr_color = nil, fade_color = nil, init_css = nil, entr_css = nil, title_text = nil, fade_time = nil)


    # Хüƥȥ֥饦CSSб֥饦ܥåȤʤɤˤϷ̤Ϥʤ

    unless @cgi.mobile_agent? || @cgi.user_agent =~ %r[(#{tdiarytimes_textstyle_ignore_user_agent})]i


	r = ""


	# ץͤɤ߹ߤ

	init_text = @options['tdiarytimes_textstyle.init_text'] || "|" unless init_text
	entr_text = @options['tdiarytimes_textstyle.entr_text'] || "|" unless entr_text
	init_color = @options['tdiarytimes_textstyle.init_color'] || "444444" unless init_color
	entr_color = @options['tdiarytimes_textstyle.entr_color'] || "eeeeee" unless entr_color
	fade_color = @options['tdiarytimes_textstyle.fade_color'] || "444444" unless fade_color
	init_css = @options['tdiarytimes_textstyle.init_css'] || "background-color:#444444;" unless init_css
	entr_css = @options['tdiarytimes_textstyle.entr_css'] || "" unless entr_css
	title_text = @options['tdiarytimes_textstyle.title_text'] || "TDIARYTIMES-TEXTSTYLE" unless title_text
	fade_time = @options['tdiarytimes_textstyle.fade_time'] || 30 unless fade_time


	entr_color_rgb = entr_color.unpack("a2a2a2")
	fade_color_rgb = fade_color.unpack("a2a2a2")

	fade_time = 24 * 60 * 60 * fade_time.to_f


	# ǡɤ߹

	cache = "#{@cache_path}/tdiarytimes_textstyle"

	begin
		io = open("#{cache}/tdiarytimes_textstyle.dat","r")
		ary_data =  Marshal.load(io)
		io.close
	rescue
		# ե뤬Ĥʤϥ顼ȥߡǡɽ
		r << %Q|Error! cannot open log file.|
		ary_data = Array.new(145) {|i| 0 }
	end


	# htmlǡν

	r << %Q|<span style="color:##{init_color};#{init_css}" title="#{title_text}">|

	(0..143).each {|i|
		data = ary_data[i]
		if data != 0
			delta = (Time.now.to_i - data)/fade_time.to_f
			if  delta < 0
				# ɥȥк
				now_color = init_color
			elsif delta > 1
				# եɥȴĶᥨȥк
				now_color = fade_color
			else
				# ʥȥν
				now_color = ""
				(0..2).each{|i|
					now_color << format("%02x", entr_color_rgb[i].hex + ((fade_color_rgb[i].hex - entr_color_rgb[i].hex)*delta).to_i)
				}
			end
			r << %Q|<span style="color:##{now_color};#{entr_css}" title="#{Time.at(data).strftime('%b %d,%Y')}">#{entr_text}</span>|
		else
			r << %Q|#{init_text}|
		end
	}

	r << %Q|</span>|

    end

end

==> tdiary_2.2.1.orig.tar.gz: tdiary-2.2.1/contrib2/plugin/tdiarytimes/tdiarytimes_textstyle.rb <==
# tdiarytimes_textstyle.rb $Revision: 1.3 $
#
# Copyright (c) 2004 phonondrive <tdiary@phonondrive.com>
# Distributed under the GPL
#
# ץ饰ۥڡ
# http://phonondrive.com/trd/
# --------------------------------------------------------------------
#
#
#
# Abstract
# --------------------------------------------------------------------
# ϿӤ򥿥饤˵Ͽޤ
# Ͽ줿ȥηвȶ˥եɥȤƤޤ
# Τ褦 MTBlogTimes  tdiarytimes ƱεǽƥȤǼ¸ޤ
# ޤƥȥ١Ǥ뤳Ȥʥȥǥ󤬲ǽǤ
# ruby-gd Υ󥹥ȡȤɬפʤᡢ˻ѽޤ
#
#
# Usage
# --------------------------------------------------------------------
# ץ饰ϡץ饰եƤ
# إå뤤ϥեåϤ <%= tdiarytimes_textstyle %>
# ΰ֤˥饤ʸŸޤ
# ȥεϿݻ֤β᤮Ťȥκϡ
# ɲäϿ˹Ԥޤ
# ȥΥեɥȸ̤ϥꥢ륿˷׻ޤ
# ȥɽʬǽ10ʬȤǤ
#
#
# Options
# --------------------------------------------------------------------
#
# ߡ9ĤΥץѰդƤޤ
#
# init_text	ϿƤʤӤʸ (Ǥդʸ)
# entr_text	Ͽ줿Ӥʸ (Ǥդʸ)
# init_color	ϿƤʤӤʸο (RRBBGGǻ)
# entr_color	Ͽ줿Ӥʸο (RRBBGGǻ)
# fade_color	Ͽ줿ӤʸΥեɥο (RRBBGGǻ)
# init_css	饤ʸΤCSS (CSSν񼰤˽)
# entr_css	Ͽ줿ӤʸCSS (CSSν񼰤˽)
# title_text	֥Ⱦ˥ޥݥȤTIPSʸ (Ǥդʸ)
# fade_time	Ȥ¸Ƥ(եɥȤפ) (Ǥդο)
# entr_interval	ΥȥϿְϿϿʤ (Ǥդο)
#
# ץͤˡˤ3Ĥˡꡢ̤ͥϼ̤Ǥ
# <%= tdiarytimes_textstyle %>   tdiary.conf  ǥե
# 
# entr_intervalƤΥץͤ <%= %> ؤΰˤ뤿ᡢ
# ڡˤȤ˰վѹʤɼͳ٤ι⤤ȥǥ󤬲ǽǤ
# ǡƤΥץ˥ǥեͤѰդƤ뤿ᡢ
# ԤʤƤưޤ
# ǥեͤζŪͤˤĤƤϡtdiary.confؤεˡι򻲾ȤƲ
#
#
# <%= tdiarytimes_textstyle %>ؤΰˤ륪ץˡ
# --------------------------------------------------------------------
#ڽ񼰡
# <%= tdiarytimes_textstyle init_text, entr_text, init_color, entr_color, fade_color, init_css, entr_css, title_text, fade_time %>
#
#ڵ 
# <%=tdiarytimes_textstyle "","","004400","66ff66","004400","background-color:#002200;font-size:9px",nil,"TEXTSTYLE!!",15 %>
#
#  tdiary.conf͡ޤϥǥեͤѤϡ nil ꤷƤ
#
#
# tdiary.confؤεҤˤ륪ץˡ
# --------------------------------------------------------------------
#ڵ (ȤƻꤵƤͤϡץ饰ΤλĥǥեͤǤ)
# @options['tdiarytimes_textstyle.init_text'] = "|"
# @options['tdiarytimes_textstyle.entr_text'] = "|"
# @options['tdiarytimes_textstyle.init_color'] = "444444"
# @options['tdiarytimes_textstyle.entr_color'] = "eeeeee"
# @options['tdiarytimes_textstyle.fade_color'] = "444444"
# @options['tdiarytimes_textstyle.init_css'] = "background-color:#444444;"
# @options['tdiarytimes_textstyle.entr_css'] = ""
# @options['tdiarytimes_textstyle.title_text'] = "TDIARYTIMES-TEXTSTYLE"
# @options['tdiarytimes_textstyle.fade_time'] = 30
# @options['tdiarytimes_textstyle.entr_interval'] = 1
#
#  fade_time ñ̤entr_interval ñ̤ϻ֤Ǥ
#  Ȥ¸Ƥ(եɥȴ)᤮ǡȥϡ
# ַвμɲû˥ե뤫ޤ
# δ֤ꤹ fade_time ͤϡ<%= %> ϻޤ
# ǥե(30)ʳͤѤϡɬ tdiary.conf ˤƻꤷƲ
# Ʊͤˡentr_interval ǥե(1)ʳꤷϡ
# tdiary.conf ˤƻꤷƲʤߤ0.530ʬֳ֤ˤʤޤ
#
#
# In secure mode
# --------------------------------------------------------------------
# ߤΤȤưޤ(եɤ߹ʤ)
#
#
# Acknowledgements
# --------------------------------------------------------------------
# This plugin is based on tdiarytimes.rb $Revision: 1.3 $
# Copyright (c) 2003 neuichi <neuichi@nmnl.jp>
# Distributed under the GPL
# http://nmnl.jp/hiki/software/?tDiary+%3A%3A+Plugin
#
#
=begin ChangeLog
2004.03.04 phonondrive  <tdiary@phonondrive.com>
   * version 1.0.4
	USER-AGENTꥹȤ򹹿ޤ

2004.02.05 phonondrive  <tdiary@phonondrive.com>
   * version 1.0.3
	եɥȸ̤η׻̤Ϥʤޤ

2004.01.30 phonondrive  <tdiary@phonondrive.com>
   * version 1.0.2
	Ͽֳ֤Υץ (entr_interval) ɲá
	ΥȥϿְϿϿʤ褦ˤޤ

2004.01.29 phonondrive  <tdiary@phonondrive.com>
   * version 1.0.1
	replace(Ͽ)⥨ȥϿ褦ˤޤ
	USER-AGENTθƤӽФˤϷ̤Ϥʤ褦ˤޤ
		Хü (tDiary)
		ƥȥ֥饦 (w3m, Lynx, links)
		CSSб֥饦 (Mosaic, Lite, iCab, JustView, WebExplorer)
		ܥå (bot, crawler, Spider, Slurp, inktomi, Sidewinder, naver)
		¾ (libwww, antenna)

2004.01.28 phonondrive  <tdiary@phonondrive.com>
   * version 1.0.0
=end




# tDiarytimes_textstyle η̤Ϥʤ USER-AGENT ꥹ
# Хüƥȥ֥饦CSSб֥饦ܥåȡƥʤʤ
# ʸʸ϶̤ޤ

def tdiarytimes_textstyle_ignore_user_agent; "w3m|Lynx|links|Mosaic|Lite|iCab|JustView|WebExplorer|bot|crawler|Spider|Slurp|inktomi|Sidewinder|naver|libwww|archiver|http|check|WDB|WWWC|WWWD|samidare|tamatebako|NATSU-MICAN|hina|antenna"; end




# --------------------------------------------------------------------
# Ͽν
# --------------------------------------------------------------------

if /^(append|replace)$/ =~ @mode then

	# ץ(ȥݻ)ɤ߹ߤ

	fade_time = @options['tdiarytimes_textstyle.fade_time'] || 30
	fade_time = 24 * 60 * 60 * fade_time.to_f

	entr_interval = @options['tdiarytimes_textstyle.entr_interval'] || 1
	entr_interval = 60 * 60 * entr_interval.to_f


	# ǡɤ߹

	cache = "#{@cache_path}/tdiarytimes_textstyle"
	Dir::mkdir( cache ) unless File::directory?( cache )

	begin
		io = open("#{cache}/tdiarytimes_textstyle.dat","r")
		ary_data =  Marshal.load(io)
		io.close

		# 1.0.1 >> 1.0.2 ǡܹ
		if ary_data.size == 144
			ary_data.push(Time.now.to_i - entr_interval - 1)
		end

	rescue
		# ʤϲǡѰ
		ary_data = Array.new(145) {|i| 0 }
	end


	# ɥǡ̿褿ȥ

	(0..143).each {|i|
		delta = (Time.now.to_i - ary_data[i])/fade_time.to_f
		if delta < 0 || delta > 1
			ary_data[i] = 0
		end
	}


	# Ͽֳ֤вᤷƤ顢Ͽ줿Ӥ˿ȥ򥻥åȤ

	if (Time.now.to_i - ary_data[144]) > entr_interval.to_f
		ary_data[(Time.now.strftime('%H').to_i*6 + Time.now.strftime('%M').to_f/10).to_i] = Time.now.to_i
		# ǽϿ֤εϿ
		ary_data[144] = Time.now.to_i 
	end


	# ǡν񤭹

	io = open("#{cache}/tdiarytimes_textstyle.dat","w")
		Marshal.dump(ary_data,io)
	io.close
end




# --------------------------------------------------------------------
# ץ饰ɽư
# --------------------------------------------------------------------

def tdiarytimes_textstyle(init_text = nil, entr_text = nil, init_color = nil, entr_color = nil, fade_color = nil, init_css = nil, entr_css = nil, title_text = nil, fade_time = nil)


    # Хüƥȥ֥饦CSSб֥饦ܥåȤʤɤˤϷ̤Ϥʤ

    unless @cgi.mobile_agent? || @cgi.user_agent =~ %r[(#{tdiarytimes_textstyle_ignore_user_agent})]i


	r = ""


	# ץͤɤ߹ߤ

	init_text = @options['tdiarytimes_textstyle.init_text'] || "|" unless init_text
	entr_text = @options['tdiarytimes_textstyle.entr_text'] || "|" unless entr_text
	init_color = @options['tdiarytimes_textstyle.init_color'] || "444444" unless init_color
	entr_color = @options['tdiarytimes_textstyle.entr_color'] || "eeeeee" unless entr_color
	fade_color = @options['tdiarytimes_textstyle.fade_color'] || "444444" unless fade_color
	init_css = @options['tdiarytimes_textstyle.init_css'] || "background-color:#444444;" unless init_css
	entr_css = @options['tdiarytimes_textstyle.entr_css'] || "" unless entr_css
	title_text = @options['tdiarytimes_textstyle.title_text'] || "TDIARYTIMES-TEXTSTYLE" unless title_text
	fade_time = @options['tdiarytimes_textstyle.fade_time'] || 30 unless fade_time


	entr_color_rgb = entr_color.unpack("a2a2a2")
	fade_color_rgb = fade_color.unpack("a2a2a2")

	fade_time = 24 * 60 * 60 * fade_time.to_f


	# ǡɤ߹

	cache = "#{@cache_path}/tdiarytimes_textstyle"

	begin
		io = open("#{cache}/tdiarytimes_textstyle.dat","r")
		ary_data =  Marshal.load(io)
		io.close
	rescue
		# ե뤬Ĥʤϥ顼ȥߡǡɽ
		r << %Q|Error! cannot open log file.|
		ary_data = Array.new(145) {|i| 0 }
	end


	# htmlǡν

	r << %Q|<span style="color:##{h init_color};#{h init_css}" title="#{h title_text}">|

	(0..143).each {|i|
		data = ary_data[i]
		if data != 0
			delta = (Time.now.to_i - data)/fade_time.to_f
			if  delta < 0
				# ɥȥк
				now_color = init_color
			elsif delta > 1
				# եɥȴĶᥨȥк
				now_color = fade_color
			else
				# ʥȥν
				now_color = ""
				(0..2).each{|i|
					now_color << format("%02x", entr_color_rgb[i].hex + ((fade_color_rgb[i].hex - entr_color_rgb[i].hex)*delta).to_i)
				}
			end
			r << %Q|<span style="color:##{h now_color};#{h entr_css}" title="#{Time.at(data).strftime('%b %d,%Y')}">#{entr_text}</span>|
		else
			r << %Q|#{init_text}|
		end
	}

	r << %Q|</span>|

    end

end
